### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Creation handle used to treat profile for use with comunity

$Id: create_profile_handle.py 52428 2009-01-31 16:37:49Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 52428 $"
 
from zope.interface import implements
from zope.interface import alsoProvides
from zope.app.securitypolicy.interfaces import IPrincipalPermissionManager

from zope.app.zapi import getUtility
from zope.app.container.interfaces import IContainer 

from ng.content.profile.friendshipannotation.interfaces import IFriendshipAnnotationAble, IFriendshipAnnotation
from ng.content.profile.friendobjectqueueannotation.interfaces import IFriendObjectQueueAnnotationAble, IFriendObjectQueueAnnotation
from ng.content.profile.exchangeannotation.interfaces import IExchangeAnnotationAble


def create_profile_handle(ob,event) :
    alsoProvides(ob, IFriendObjectQueueAnnotationAble)
    alsoProvides(ob, IFriendshipAnnotationAble)
    alsoProvides(ob, IExchangeAnnotationAble)

    oqa = IFriendObjectQueueAnnotation(ob) 
    oqa.order = u'straight'
    oqa.maxlen = 40
    



### -*- coding: utf-8 -*- #############################################
#######################################################################
"""installAbout, installArticles, installMirrors, installNews, installRubric
and installRubrics scripts for the Zope 3 based ng.site.content.install package

$Id: install_content.py 52501 2009-02-10 21:43:24Z cray $
"""
__author__  = "Yegor Shershnev, 2007"
__license__ = "GPL"
__version__ = "$Revision: 52501 $"

from zope.app.folder.folder import Folder

from zope.app.component.hooks import setSite
from zope.app.component import site

from ng.content.article.division.division import Division
from ng.content.article.article.article import Article
from ng.app.objectqueue.interfaces import IObjectQueueAnnotation
from zope.app.container.interfaces import IContainer

def installCommunity(context, **kw):
    """ Создаёт раздел Community
    """

    community = context[u'community'] = Division()

    community.title = kw['community']
    community.author = kw['author']
    IObjectQueueAnnotation(community).use = False

    sm = context.getSiteManager()
    sm.registerUtility(context[u'community'], provided=IContainer, name=u'community')

    return "Success"




### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Interfaces for the Zope 3 based product package

$Id: interfaces.py 52221 2008-12-27 15:01:41Z cray $
"""
__author__  = "Andrey Orlov, 2008"
__license__ = "GPL"
__version__ = "$Revision: 52221 $"
 

from zope.schema import Field
from zope.interface import Interface
from ng.lib.containconstraint import ContainConstraint

class IDenyContainCommunity_(Interface) :
    """ """

class IDenyContainCommunity(IDenyContainCommunity_) :
    __parent__ = Field(constraint = ContainConstraint(IDenyContainCommunity_).deny)
    
    


### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Factories for division class used as community

$Id: community.py 52428 2009-01-31 16:37:49Z cray $
"""
__author__  = "Andrey Orlov"
__license__ = "GPL"
__version__ = "$Revision: 52428 $"
 
from zope.interface import implements
from ng.content.article.division.division import Division
from ng.content.profile.friendshipannotation.interfaces import IFriendshipAnnotationAble, IFriendshipAnnotation
from ng.content.article.interfaces import IDocShortLogo
from zope.security.proxy import removeSecurityProxy
from zope.interface import alsoProvides
from zope.app.securitypolicy.interfaces import IPrincipalPermissionManager
from ng.app.objectqueue.interfaces import  IObjectQueueAnnotation
from ng.content.profile.communityobjectqueueannotation.interfaces import ICommunityObjectQueueAnnotationAble, ICommunityObjectQueueAnnotation
from ng.content.comment.interfaces import ICommentAnnotationAble
from interfaces import ICommunityAnnotable


from zope.app.zapi import getUtility
from zope.app.container.interfaces import IContainer 

def CommunityCreate(principal) :
    division = Division()
    alsoProvides(division, IFriendshipAnnotationAble)
    alsoProvides(division, IDocShortLogo)
    alsoProvides(division, ICommunityObjectQueueAnnotationAble)
    alsoProvides(division, ICommunityAnnotable)
    alsoProvides(division, ICommentAnnotationAble)

    for oqa in IObjectQueueAnnotation(division), ICommunityObjectQueueAnnotation(division) :
        oqa.order = u'straight'
        oqa.maxlen = 40

    IObjectQueueAnnotation(division).use = False
    
    principal_perms = IPrincipalPermissionManager(division)
    principal_perms.grantPermissionToPrincipal('zope.ManageContent', principal)
    principal_perms.grantPermissionToPrincipal('smartimage.Edit', principal)

    root_perms = IPrincipalPermissionManager(getUtility(IContainer,name='Main'))
    
    root_perms.grantPermissionToPrincipal("dreambot.ProfileServices",principal)
    root_perms.grantPermissionToPrincipal("dreambot.AddComment",principal)
    root_perms.grantPermissionToPrincipal("dreambot.ObjectQueueHandle",principal)

    return division


def Community(context) :
    return CommunityCreate(context.request.principal.id)
    